@@ -230,7 +230,14 @@ def convert_argument_to_port(
         if hasattr(cls, "__args__"):
             if cls.__args__[1] == type(None):
                 return convert_argument_to_port(
-                    cls.__args__[0], key, registry, default=default, nullable=True
+                    cls.__args__[0],
+                    key,
+                    registry,
+                    default=default,
+                    nullable=True,
+                    widget=widget,
+                    annotations=annotations,
+                    description=description,
                 )
 
     if inspect.isclass(cls):
@@ -297,9 +304,12 @@ def convert_argument_to_port(
                 description=description,
             )
 
+    print(widget)
+
     identifier = registry.get_identifier_for_structure(cls)
     default_converter = registry.get_default_converter_for_structure(cls)
     widget = widget or registry.get_widget_input(cls)
+    print(widget)
 
     return ArgPortInput(
         kind=PortKindInput.STRUCTURE,
@@ -377,7 +387,12 @@ def convert_return_to_returnport(
         if hasattr(cls, "__args__"):
             if cls.__args__[1] == type(None):
                 return convert_return_to_returnport(
-                    cls.__args__[0], key, registry, nullable=True
+                    cls.__args__[0],
+                    key,
+                    registry,
+                    nullable=True,
+                    annotations=annotations,
+                    description=description,
                 )
 
     if inspect.isclass(cls):
@@ -465,7 +480,6 @@ def prepare_definition(
     sig = inspect.signature(function)
     widgets = widgets or {}
     interfaces = interfaces or []
-
     # Generate Args and Kwargs from the Annotation
     args: List[ArgPortInput] = []
     returns: List[ReturnPortInput] = []
@@ -488,16 +502,6 @@ def prepare_definition(
         for index, param in enumerate(docstring.many_returns)
     }
 
-    for port in args:
-        if port.key in doc_param_map:
-            updates = doc_param_map[port.key]
-            port.description = updates["description"] or port.description
-
-    for port in returns:
-        if port.key in doc_returns_map:
-            updates = doc_returns_map[port.key]
-            port.description = updates["description"] or port.description
-
     for index, (key, value) in enumerate(function_ins_annotation.items()):
 
         # We can skip arguments if the builder is going to provide additional arguments
@@ -510,6 +514,7 @@ def prepare_definition(
 
         widget = widgets.get(key, None)
         cls = value.annotation
+        print(widget)
 
         try:
             args.append(
