@@ -18,9 +18,4 @@ class BasePostman(KoiledModel):
 
     """
 
-    async def __aenter__(self):
-        current_postman.set(self)
-        return self
-
-    async def __aexit__(self, exc_type, exc_val, exc_tb):
-        current_postman.set(None)
+    connected = Field(default=False)
